# FMCloud Util class 
# Initiate the class with host name, user name and password. 
# After initiate the class, can call the login, which will get the token and save in the class.
# All the following calls will be using that token.
# -*- coding: utf-8 -*-
import requests
import json
import time
import pprint
import subprocess
from subprocess import call


class FmRest:
	def __init__ (self, hostName, adminUserName, adminPassword):
		self.hostUrl = "https://" + hostName + "/"
		self.userName = adminUserName
		self.password = adminPassword
		self.client = requests.session()
		self.dummyJson = {}
		self.sessionKey = ""
		self.header = ""

	def getSessionKey (self):
		return self.sessionKey
			
	def login (self):
		payload = {'username':self.userName, 'password': self.password}
		#print payload
		loginHeaders = {"Content-Type": "application/json; charset=UTF-8"}
		r = self.client.post(self.hostUrl + 'admin/api/v1/user/login', json=payload, headers=loginHeaders)
		#print r
		loginResult = r.json()		
		if('token' in loginResult):
			sessionKey = loginResult['token']
			self.sessionKey = sessionKey
			self.genRestHeaders()
		return loginResult		

	def genRestHeaders(self):
		headers= {'Content-Type': 'application/json; charset=UTF-8', 'authorization': 'Bearer ' + self.sessionKey}
		self.headers = headers
		return headers
		
	def getFileList(self):
		filelist = self.client.get(self.hostUrl + 'admin/api/v1/databases', headers=self.headers)
		if(filelist.json()):
			parsed_json = filelist.json()					 
		return parsed_json

	def openDB(self, fileId, keyValue):
		openDBPayload ={ 'key' : keyValue, 'savekey': 'true'}
		openDbResult= self.client.put(self.hostUrl + 'admin/api/v1/databases/' + str(fileId) + '/open' , 
		json=openDBPayload, headers=self.headers)
		return openDbResult.json()

	def closeDB(self, fileId, message):
		closeDBPayload ={ 'message' : message}
		closeDb1Result= self.client.put(self.hostUrl + 'admin/api/v1/databases/'+ str(fileId) + '/close' , json=closeDBPayload, headers=self.headers)
		return closeDb1Result.json()

	def sendMsg(self, clientId, message):	
		sendmsgPayload ={'message':  message} 
		sendMsgResult = self.client.post(self.hostUrl + 'admin/api/v1/clients/' + str(clientId) + '/message' , 
		json=sendmsgPayload, headers=self.headers)
		return sendMsgResult.json()

	def disconnect(self, clientId, message, gracetime):
		disconnectPayload ={'message':  message, 'gracetime': gracetime}
		disconnectResult = self.client.put(self.hostUrl + 'admin/api/v1/clients/' + str(clientId) + '/disconnect', 
		json=disconnectPayload, headers=self.headers)		
		return disconnectResult.json()

	def pauseDB(self, fileId):
		pauseDb1Result= self.client.put(self.hostUrl + 'admin/api/v1/databases/' + str(fileId) + '/pause', headers=self.headers)		
		return pauseDb1Result.json()

	def resumeDB(self, fileId):
		resumeDb1Result= self.client.put(self.hostUrl + 'admin/api/v1/databases/' + str(fileId) + '/resume', headers=self.headers)		
		return resumeDb1Result.json()

	def createSchedule(self, createSchedulePayload):
		createScheduleResult= self.client.post(self.hostUrl + 'admin/api/v1/schedules' , 
		json= createSchedulePayload, headers=self.headers)
		return createScheduleResult.json()
		
	def editSchedule(self, editSchedulePayload, scheduleId):
		editScheduleResult= self.client.put(self.hostUrl + 'admin/api/v1/schedules/' + scheduleId , 
		json= editSchedulePayload, headers=self.headers)
		return editScheduleResult.json()
		
	def runSchedule(self, scheduleId):
		runScheduleResult= self.client.put(self.hostUrl + 'admin/api/v1/schedules/' + scheduleId + '/run', 
		headers=self.headers)
		return runScheduleResult.json()

	def duplicateSchedule(self, scheduleId):
		duplicateScheduleResult= self.client.post(self.hostUrl + 'admin/api/v1/schedules/' + scheduleId +'/duplicate', 
		headers=self.headers)	
		return duplicateScheduleResult.json()

	def deleteSchedule(self, scheduleId):
		deleteScheduleResult= self.client.delete(self.hostUrl + 'admin/api/v1/schedules/' + scheduleId , 
		headers=self.headers)
		return deleteScheduleResult.json()
		
	def enableSchedule(self, scheduleId):
		enableScheduleResult= self.client.put(self.hostUrl + 'admin/api/v1/schedules/' + scheduleId +'/enable', 
		headers=self.headers)			
		return enableScheduleResult.json()
		
	def disableSchedule(self, scheduleId):
		disableScheduleResult= self.client.put(self.hostUrl + 'admin/api/v1/schedules/' + scheduleId +'/disable', 
		headers=self.headers)	
		return disableScheduleResult.json()
	
	def getSchedules(self, scheduleId):
		scheduleIdStr = ""
		if scheduleId is not None and len(scheduleId) > 0 :
			scheduleIdStr = "/" + scheduleId
		print scheduleIdStr	
		getScheduleResult= self.client.get(self.hostUrl + 'admin/api/v1/schedules' + scheduleIdStr, 
		 headers=self.headers)
		return getScheduleResult.json()

	def logout(self):
		r = self.client.post(self.hostUrl + 'admin/api/v1/user/logout', json='', headers=self.headers)
		return r.json()

	def weeklyMaintenance(self):		
		dbList = self.getFileList()
		print dbList
		closeDBResult = self.closeDB(0, "DB Shutdown!")
		print closeDBResult
		time.sleep(90)

	def queryDBSforDBName(self, dbName):
		dbList = self.getFileList()
		output = None	
		for item in dbList['files']['files']:
			if (item['filename']==dbName) :
				output = item
				return output
				
		return output # only happen when output None
		